@@ -125,13 +125,17 @@ def main(arglist):
         name=smoothing + "_model", exp_info=exp)
 
     model_base = op.join(analysis_dir, "{subject_id}/preproc/run_*/")
-    design_file = exp["design_name"] + ".csv"
     model_templates = dict(
-        design_file=op.join(data_dir, "{subject_id}/design", design_file),
+        timeseries=op.join(model_base, smoothing + "_timeseries.nii.gz"),
         realign_file=op.join(model_base, "realignment_params.csv"),
         artifact_file=op.join(model_base, "artifacts.csv"),
-        timeseries=op.join(model_base, smoothing + "_timeseries.nii.gz"),
-                           )
+        )
+
+    if exp["design_name"] is not None:
+        design_file = exp["design_name"] + ".csv"
+        regressor_file = exp["design_name"] + ".csv"
+        model_templates["design_file"] = op.join(data_dir, "{subject_id}",
+                                                    "design", design_file)
     if exp["regressor_file"] is not None:
         regressor_file = exp["regressor_file"] + ".csv"
         model_templates["regressor_file"] = op.join(data_dir, "{subject_id}",
@@ -166,10 +170,12 @@ def main(arglist):
 
     # Retrieve the right workflow function for registration
     # Get the workflow function dynamically based on the space
+    warp_method = project["normalization"]
     flow_name = "%s_%s_reg" % (space, regtype)
     reg, reg_input, reg_output = wf.create_reg_workflow(flow_name,
                                                         space,
-                                                        regtype)
+                                                        regtype,
+                                                        warp_method)
 
     # Define a smoothing info node here. Use an iterable so that running
     # with/without smoothing doesn't clobber working directory files
@@ -181,15 +187,15 @@ def main(arglist):
     # Set up the registration inputs and templates
     reg_templates = dict(
         masks="{subject_id}/preproc/run_*/functional_mask.nii.gz",
-        affines="{subject_id}/preproc/run_*/func2anat_flirt.mat"
-                          )
+                         )
 
     if regtype == "model":
         reg_base = "{subject_id}/model/{smoothing}/run_*/"
         reg_templates.update(dict(
+            means="{subject_id}/preproc/run_*/mean_func.nii.gz",
             copes=op.join(reg_base, "cope*.nii.gz"),
             varcopes=op.join(reg_base, "varcope*.nii.gz"),
-            ss_files=op.join(reg_base, "ss*.nii.gz"),
+            sumsquares=op.join(reg_base, "ss*.nii.gz"),
                                   ))
     else:
         reg_templates.update(dict(
@@ -199,8 +205,17 @@ def main(arglist):
     reg_lists = reg_templates.keys()
 
     if space == "mni":
+        aff_ext = "mat" if warp_method == "fsl" else "txt"
         reg_templates["warpfield"] = op.join(data_dir, "{subject_id}",
                                              "normalization/warpfield.nii.gz")
+        reg_templates["affine"] = op.join(data_dir, "{subject_id}",
+                                          "normalization/affine." + aff_ext)
+
+    rigid_stem = "{subject_id}/preproc/run_*/func2anat_"
+    if warp_method == "ants" and space == "mni":
+        reg_templates["rigids"] = rigid_stem + "tkreg.dat"
+    else:
+        reg_templates["rigids"] = rigid_stem + "flirt.mat"
 
     # Define the registration data source node
     reg_source = Node(SelectFiles(reg_templates,
@@ -256,8 +271,10 @@ def main(arglist):
         copes=op.join(ffx_base, "cope*" + ext),
         varcopes=op.join(ffx_base, "varcope*" + ext),
         masks=op.join(ffx_base, "functional_mask" + ext),
+        means=op.join(ffx_base, "mean_func" + ext),
         dofs="{subject_id}/model/{smoothing}/run_*/results/dof",
         ss_files=op.join(ffx_base, "ss*" + ext),
+        timeseries="{subject_id}/preproc/run_*/{smoothing}_timeseries.nii.gz",
                          )
     ffx_lists = ffx_templates.keys()
 
